@@ -9,6 +9,12 @@ sub new {
 
 };
 
+sub getMatrix {
+  my $self = shift;
+
+  return $self->{matrix};
+}
+
 sub setMatrix {
     my ($self, $m) = @_;
 
