@@ -22,17 +22,17 @@ sub ditherBlue {
 
   my $matrix = $matrixbitmapobj->getMatrix;
   
-  my $pngbppmultiplynumber = 4; ### R,G,B and A
+  my $pngbppmultiplynumber = 4 - 1; ### R,G,B and A
     
-    for (my $j = 0; $j < $matrix->getRowsNumber * $pngbppmultiplynumber; $j++) {
-      for (my $i = 0; $i < $matrix->getColumnsNumber; $i++) {
-	for (my $rgbanumber = $pngbppmultiplynumber; $rgbanumber > 0; $rgbanumber--) {
-	  if ($rgbanumber == 3) { ### choose blue in the matrix
-	    $matrix->setAtIndex($j, $i, hex(@rowofbytes[$j][$i]));
+  for (my $j = 0; $j < $matrix->getRowsNumber * $pngbppmultiplynumber; $j++) {
+    for (my $i = 0; $i < $matrix->getColumnsNumber; $i++) {
+      for (my $rgbanumber = $pngbppmultiplynumber; $rgbanumber >= 0; $rgbanumber--) {
+	if ($rgbanumber == 2) { ### choose blue in the matrix
+	  $matrix->setAtIndex($j, $i, hex(floor($matrix->indexOf($j,$i) * $self->{percentage})));
 	}
       }
     }
-  
+  } 
   ### NOTE : returns a class
   return MatrixBitmap->new->setMatrix($matrix);
 }
