@@ -6,10 +6,10 @@ use parent 'OnePassBitmapAlgorithmComponent';
 sub new {
     my $class = shift;
 
-    $self = SUPER::OnePassBitmapAlgorithmComponent->new;
+    $self = SUPER::OnePassBitmapAlgorithmComponent->new(BagElement1);
 
     ### 1. matrixbitmap is temporary output of the functor for example
-    $self = { matrixbitmap => undef, };
+    $self = { matrixbitmap => undef, index => -1, };
     
     bless $self, $class;
 }
