@@ -1,11 +1,14 @@
-### base class of several features of the one pass algorithm
+### base class of several features of the one pass algorithm, a list of functors
+
+### NOTE : This is set as a parent : 'BagElement1'
 
 use 'GFX-Tools-Buffer::toolsarray';
 
 sub new {
-    my $class = shift;
+    my ($class, $ElementClass) = @_; ### $ElementClass e.g. BagElement1.pm
 
-    $self = { functors => toolsarray->new, };
+    $self = SUPER::$ElementClass->new;
+    $self->{functors} = toolsarray->new;
     
     bless $self, $class;
 }
